# Clients

## Wallhaven

```{eval-rst}
.. autoclass:: xanax.sources.wallhaven.client.Wallhaven
   :members:
   :special-members: __init__, __enter__, __exit__, __repr__
```

```{eval-rst}
.. autoclass:: xanax.sources.wallhaven.async_client.AsyncWallhaven
   :members:
   :special-members: __init__, __aenter__, __aexit__, __repr__
```

---

## Unsplash

```{eval-rst}
.. autoclass:: xanax.sources.unsplash.client.Unsplash
   :members:
   :special-members: __init__, __enter__, __exit__, __repr__
```

```{eval-rst}
.. autoclass:: xanax.sources.unsplash.async_client.AsyncUnsplash
   :members:
   :special-members: __init__, __aenter__, __aexit__, __repr__
```

---

## Reddit

```{eval-rst}
.. autoclass:: xanax.sources.reddit.client.Reddit
   :members:
   :special-members: __init__, __enter__, __exit__, __repr__
```

```{eval-rst}
.. autoclass:: xanax.sources.reddit.async_client.AsyncReddit
   :members:
   :special-members: __init__, __aenter__, __aexit__, __repr__
```
